Opts

Struct Opts 

pub(crate) struct Opts {
Show 18 fields pub(crate) exit_dump_len: u32, pub(crate) slice_us: u64, pub(crate) slice_us_lag: u64, pub(crate) throttle_us: u64, pub(crate) idle_resume_us: i64, pub(crate) tickless: bool, pub(crate) rr_sched: bool, pub(crate) primary_domain: String, pub(crate) disable_smt: bool, pub(crate) disable_numa: bool, pub(crate) cpufreq: bool, pub(crate) stats: Option<f64>, pub(crate) monitor: Option<f64>, pub(crate) debug: bool, pub(crate) verbose: bool, pub(crate) version: bool, pub(crate) help_stats: bool, pub libbpf: LibbpfOpts,
}

Fields

exit_dump_len: u32

Exit debug dump buffer length. 0 indicates default.

slice_us: u64

Maximum scheduling slice duration in microseconds.

slice_us_lag: u64

Maximum runtime budget that a task can accumulate while sleeping (in microseconds).

Increasing this value can help to enhance the responsiveness of interactive tasks, but it can also make performance more “spikey”.

throttle_us: u64

Throttle the running CPUs by periodically injecting idle cycles.

This option can help extend battery life on portable devices, reduce heating, fan noise and overall energy consumption (0 = disable).

idle_resume_us: i64

Set CPU idle QoS resume latency in microseconds (-1 = disabled).

Setting a lower latency value makes CPUs less likely to enter deeper idle states, enhancing performance at the cost of higher power consumption. Alternatively, increasing the latency value may reduce performance, but also improve power efficiency.

tickless: bool

Enable tickless mode.

This option enables tickless mode: tasks get an infinite time slice and they are preempted only in case of CPU contention. This can help reduce the OS noise and provide a better level of performance isolation.

rr_sched: bool

Enable round-robin scheduling.

Each task is given a fixed time slice (defined by –slice-us) and run in a cyclic, fair order.

primary_domain: String

Specifies the initial set of CPUs, represented as a bitmask in hex (e.g., 0xff), that the scheduler will use to dispatch tasks, until the system becomes saturated, at which point tasks may overflow to other available CPUs.

Special values:

  • “auto” = automatically detect the CPUs based on the active power profile
  • “turbo” = automatically detect and prioritize the CPUs with the highest max frequency
  • “performance” = automatically detect and prioritize the fastest CPUs
  • “powersave” = automatically detect and prioritize the slowest CPUs
  • “all” = all CPUs assigned to the primary domain
  • “none” = no prioritization, tasks are dispatched on the first CPU available
disable_smt: bool

Disable SMT awareness.

disable_numa: bool

Disable NUMA rebalancing.

cpufreq: bool

Enable CPU frequency control (only with schedutil governor).

With this option enabled the CPU frequency will be automatically scaled based on the load.

stats: Option<f64>

Enable stats monitoring with the specified interval.

monitor: Option<f64>

Run in stats monitoring mode with the specified interval. Scheduler is not launched.

debug: bool

Enable BPF debugging via /sys/kernel/tracing/trace_pipe.

verbose: bool

Enable verbose output, including libbpf details.

version: bool

Print scheduler version and exit.

help_stats: bool

Show descriptions for statistics.

libbpf: LibbpfOpts